@@ -19,6 +19,7 @@
 #include <tests/test-utils.h>
 #include <buffy/config/config.h>
 #include <buffy/mailfolder/mailbox.h>
+#include <cstdlib>
 
 using namespace std;
 
@@ -141,6 +142,14 @@ void to::test<6> ()
 	ensure_equals(conf1.locations().size(), 4u);
 }
 
+// Loading an empty file should not die
+template<> template<>
+void to::test<7> ()
+{
+    system("rm -f foo.txt; touch foo.txt");
+    config::Config conf("foo.txt");
+}
+
 }
 
 // vim:set ts=4 sw=4:
