@@ -4,7 +4,7 @@
 /*
  * Commodity wrappers for system functions
  *
- * Copyright (C) 2003--2008  Enrico Zini <enrico@debian.org>
+ * Copyright (C) 2003--2011  Enrico Zini <enrico@debian.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -29,16 +29,6 @@
 
 namespace buffy {
 
-class Directory
-{
-	DIR* dir;
-
-public:
-	Directory(const std::string& name);
-	~Directory() { closedir(dir); }
-	struct dirent* read() { return readdir(dir); }
-};
-
 class InodeSet : protected std::set<ino_t>
 {
 public:
@@ -51,21 +41,6 @@ public:
 	bool has(ino_t inode) { return find(inode) != end(); }
 };
 
-/**
- * Stat the given file, throwing exception if stat fails.
- */
-void stat(const std::string& name, struct stat* st);
-
-/**
- * Stat the given file, throwing exception if stat fails, but not in case the
- * file doesn't exist.
- *
- * @returns
- *   true if the file exists, false if the file does not exist.  If the file
- *   does not exist, 'st' is untouched.
- */
-bool statIfFound(const std::string& name, struct stat* st);
-
 }
 
 // vim:set ts=4 sw=4:
